hierarch.resampling.Bootstrapper
================================

.. currentmodule:: hierarch.resampling

.. autoclass:: Bootstrapper
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __call__, __add__, __mul__

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~Bootstrapper.fit
      ~Bootstrapper.transform
   
   

   
   
   